/**
 * @license loisolire-au-input-angular-library
 * MIT license
 */

import { __decorate, __metadata } from 'tslib';
import { HostListener, Directive, Input, ContentChild, HostBinding, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

let InputSearchDirective = class InputSearchDirective {
    constructor() {
        this.focus = false;
    }
    onFocus() {
        this.focus = true;
    }
    onBlur() {
        this.focus = false;
    }
};
__decorate([
    HostListener('focus'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], InputSearchDirective.prototype, "onFocus", null);
__decorate([
    HostListener('blur'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], InputSearchDirective.prototype, "onBlur", null);
InputSearchDirective = __decorate([
    Directive({
        selector: 'au-fa-input input'
    }),
    __metadata("design:paramtypes", [])
], InputSearchDirective);

let AuFaInputComponent = class AuFaInputComponent {
    constructor() {
        this.icon = '';
    }
    get focus() {
        return this.input ? this.input.focus : false;
    }
    get classes() {
        const cssClasses = {};
        if (this.icon) {
            cssClasses['fa-' + this.icon] = true;
        }
        return cssClasses;
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], AuFaInputComponent.prototype, "icon", void 0);
__decorate([
    ContentChild(InputSearchDirective, { static: false }),
    __metadata("design:type", InputSearchDirective)
], AuFaInputComponent.prototype, "input", void 0);
__decorate([
    HostBinding('class.input-search-focus'),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [])
], AuFaInputComponent.prototype, "focus", null);
AuFaInputComponent = __decorate([
    Component({
        selector: 'au-fa-input',
        template: "<i [ngClass]=\"classes\" class=\"fa icon\"></i>\r\n<ng-content></ng-content>\r\n",
        styles: ["i {\n  width: 25px;\n  text-align: center;\n  padding: 0 2px 0 5px;\n  border: none; }\n\n:host {\n  border-width: 1px;\n  border-style: solid;\n  padding: 1px 0;\n  display: inline-block;\n  height: 30px; }\n  :host ::ng-deep input {\n    vertical-align: middle;\n    border: none;\n    outline: none;\n    height: 100%;\n    margin: 1px 0;\n    box-sizing: border-box; }\n  :host i {\n    vertical-align: middle; }\n  :host .input-search-focus {\n    outline: none;\n    border-width: 1px;\n    border-style: solid; }\n\n:host-context(.au-fa-input-red-theme) {\n  border-color: red; }\n  :host-context(.au-fa-input-red-theme).input-search-focus {\n    border-color: red;\n    -webkit-box-shadow: 0 0 5px red;\n    box-shadow: 0 0 5px red; }\n\n:host {\n  border-color: lightgray;\n  background: white; }\n  :host.input-search-focus {\n    border-color: #4D90FE;\n    -webkit-box-shadow: 0 0 5px #4D90FE;\n    box-shadow: 0 0 5px #4D90FE; }\n"]
    }),
    __metadata("design:paramtypes", [])
], AuFaInputComponent);

let AuMdInputComponent = class AuMdInputComponent {
    constructor() {
        this.icon = '';
    }
    get focus() {
        return this.input ? this.input.focus : false;
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], AuMdInputComponent.prototype, "icon", void 0);
__decorate([
    ContentChild(InputSearchDirective, { static: false }),
    __metadata("design:type", InputSearchDirective)
], AuMdInputComponent.prototype, "input", void 0);
__decorate([
    HostBinding('class.input-search-focus'),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [])
], AuMdInputComponent.prototype, "focus", null);
AuMdInputComponent = __decorate([
    Component({
        selector: 'au-md-input',
        template: "<i class=\"material-icons md-18\" [innerHTML]=\"icon\"></i>\r\n<ng-content></ng-content>\r\n",
        styles: ["i {\n  width: 25px;\n  text-align: center;\n  padding: 0 2px 0 5px;\n  border: none; }\n\n:host {\n  border-width: 1px;\n  border-style: solid;\n  padding: 1px 0;\n  display: inline-block;\n  height: 30px; }\n  :host ::ng-deep input {\n    vertical-align: middle;\n    border: none;\n    outline: none;\n    height: 100%;\n    margin: 1px 0;\n    box-sizing: border-box; }\n  :host i {\n    vertical-align: middle; }\n  :host .input-search-focus {\n    outline: none;\n    border-width: 1px;\n    border-style: solid; }\n\n:host-context(.au-fa-input-red-theme) {\n  border-color: red; }\n  :host-context(.au-fa-input-red-theme).input-search-focus {\n    border-color: red;\n    -webkit-box-shadow: 0 0 5px red;\n    box-shadow: 0 0 5px red; }\n\n:host {\n  border-color: lightgray;\n  background: white; }\n  :host.input-search-focus {\n    border-color: #4D90FE;\n    -webkit-box-shadow: 0 0 5px #4D90FE;\n    box-shadow: 0 0 5px #4D90FE; }\n"]
    }),
    __metadata("design:paramtypes", [])
], AuMdInputComponent);

let AuInputModule = class AuInputModule {
};
AuInputModule = __decorate([
    NgModule({
        imports: [CommonModule],
        declarations: [AuFaInputComponent, InputSearchDirective, AuMdInputComponent],
        exports: [AuFaInputComponent, InputSearchDirective, AuMdInputComponent]
    })
], AuInputModule);

// Public classes.

/**
 * Angular library starter
 * Build an Angular library compatible with AoT compilation & Tree shaking like an official package
 * Copyright Roberto Simonetti
 * MIT license
 * https://github.com/robisim74/loisolire-au-input-angular-library
 */
// This file only reexports content of the `src` folder. Keep it that way.

/**
 * Generated bundle index. Do not edit.
 */

export { AuFaInputComponent, AuInputModule, AuMdInputComponent, InputSearchDirective };
//# sourceMappingURL=loisolire-au-input-angular-library.js.map
